#
# spec file for package python-fontParts
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

Name:           python-fontParts%{psuffix}
Version:        0.12.1
Release:        2.2
Summary:        API for interacting with the parts of fonts
License:        MIT
URL:            https://github.com/robotools/fontParts
Source:         https://files.pythonhosted.org/packages/source/f/fontParts/fontParts-%{version}.zip
# PATCH-FIX-UPSTREAM fontParts-pr720-py312tests.patch gh#robotools/fontParts#720
Patch0:         https://github.com/robotools/fontParts/pull/720.patch#/fontParts-pr720-py312tests.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# install_requires = [FontTools[ufo,lxml,unicode]
Requires:       python-FontTools >= 4.28.5
Requires:       python-fs >= 2.2.0
Requires:       python-lxml >= 4.0
%if %python_version_nodots < 39
Requires:       python-unicodedata2
%endif
Requires:       python-booleanOperations >= 0.9.0
Requires:       python-defcon >= 0.10.0
Requires:       python-fontMath >= 0.9.1
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module FontTools >= 4.28.5}
BuildRequires:  %{python_module booleanOperations >= 0.9.0}
BuildRequires:  %{python_module defcon >= 0.10.0}
BuildRequires:  %{python_module fontMath >= 0.9.1}
BuildRequires:  %{python_module fontPens >= 0.2.4}
BuildRequires:  %{python_module fs >= 2.2.0}
BuildRequires:  %{python_module lxml >= 4.0}
BuildRequires:  %{python_module unicodedata2 if %python-base < 3.9}
# /SECTION
%endif
%python_subpackages

%description
An API for interacting with the parts of fonts during the font development process.

%prep
%autosetup -p1 -n fontParts-%{version}

%build
export LANG=C.UTF-8
%pyproject_wheel

%install
%if !%{with test}
export LANG=C.UTF-8
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
# fontParts tests requires fontPens and fontPens' tests require fontParts
%check
export LANG=C.UTF-8
export PYTHONDONTWRITEBYTECODE=1
%python_expand PYTHONPATH=./Lib $python Lib/fontParts/fontshell/test.py -v
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/fontParts
%{python_sitelib}/fontParts-%{version}.dist-info
%endif

%changelog
* Sun Mar  3 2024 Ben Greiner <code@bnavigator.de>
- Build PEP517 wheel
- Clean old flavor directives
- Add fontParts-pr720-py312tests.patch gh#robotools/fontParts#720
  for python312 compatibility
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Tweak to logic of `setStartSegment`
- update to 0.12.0:
  * Fixes to `setStartSegment` so that it keeps the start point
    on-curve and prevents setting a setting a start segment on an
    open contour (issues #709 and #412). Thanks @typesupply!
  * Fixes to docs and test setup. Boring things.
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.11.0
  * Expose the mathGlyph options. Thanks @typesupply! See #672
  * Set defaultLayer to "public.default" when its available. Fixes issue #674. Thanks @typemytype! See #675.
  * Add info.update to the info object. Thanks @typesupply! See #676
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 0.10.8
  * add contour.setStartPoint + test by @typemytype in #668
- version update to 0.10.7
  * Update fonttools to 4.34.4 by @pyup-bot in #659
  * Update setuptools_scm to 7.0.5 by @pyup-bot in #660
  * move the code example above the list by @typemytype in #661
- version update to 0.10.6
  * Implement OpenFonts. by @typesupply in #651
- version update to 0.10.5
  * Add implementation for glyph.autoContourOrder() by @roberto-arista in #646
- version update to 0.10.4
  * copy and change the glyph.name when ever the name is not the same by @typemytype in #634
- version update to 0.10.3
  * fix doc strings for getCharacterMapping and getReverseComponentMapping by @arialcrime in #626
  * force change the default layer name to the source defaultLayerName by @typemytype in #630
* Wed Feb 16 2022 pgajdos@suse.com
- version update to 0.10.2
  0.10.1 (released 2021-12-28)
  - --------------------------
  - Update to use Collections.abc.Hashable by @benkiel in #622
  - Start testing Python 3.10 by @benkiel in #619
  0.10.0 (released 2021-12-28)
  - --------------------------
  - 2021-12-28: Drops support for Python 3.6
  - 2021-12-14: Adds tempLib, #615 (thanks @typemytype!)
  - Improved docs with #605 and #607. Thanks @driehuis and @arrowtype!
* Thu Dec 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.9.11
  * Fixes inserting a segment with an open contour, #601
- Skip python36: FontTools dropped support
* Tue Mar 23 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 0.9.10
  * Update to Defcon 0.8.0
- Release 0.9.9
  * Fixed import of version.
- Release 0.9.8
  * Add support for quadratic curves with no on-curve points in
    Contour and Segment.
- Release 0.9.7
  * Change to github actions for CI and release.
  * fontShell returns None when referenced file name doesn't exist
    for an Image
- Release 0.9.6
  * fontShell has changed() implemented now
- Release 0.9.5
  * Fix for contours not getting updated in fontShell
  * Fix for error message in normalizeKerningKey
- Release 0.9.4
  * Fixed release build
- Release 0.9.3
  * All rounding uses otRound. #536, fixes #533.
  * Allow contour.segment to be empty (#480).
  * Image file names now get a png file extension (#482).
  * Fixed error in setting contour index (#488).
  * Fixed error in PointPositionMixin (#486, fixed by #491)
  * Added option to turn off normalizer tests
  * Test fixes and updates. #512.
  * various: Documentation updates and corrections
- reinstate python36 build (python36-FontTools is available)
- skip python2 for Leap
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 36 (no FontTools as that requries scipy)
* Wed May 20 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-fontParts
